#
# spec file for package lzfse
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           lzfse
Version:        1.0
Release:        2.17
Summary:        Reference C implementation of the LZFSE compressor
License:        BSD-3-Clause
Group:          Productivity/Archiving/Compression
URL:            https://github.com/lzfse/lzfse
Source:         https://github.com/lzfse/lzfse/archive/%{name}-%{version}.tar.gz
BuildRequires:  cmake

%description
LZFSE is a Lempel-Ziv style data compression algorithm using Finite State
Entropy coding. It targets similar compression rates at higher compression
and decompression speed compared to deflate using zlib.

%package devel
Summary:        Reference C implementation of the LZFSE compressor
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
LZFSE is a Lempel-Ziv style data compression algorithm using Finite State
Entropy coding. It targets similar compression rates at higher compression
and decompression speed compared to deflate using zlib.

This package contains devel files.

%prep
%setup -q -n %{name}-%{name}-%{version}

%build
%cmake \
  -Wno-dev
%cmake_build

%install
%cmake_install

%files
%doc README.md
%license LICENSE
%{_bindir}/lzfse
%{_libdir}/liblzfse.so

%files devel
%{_includedir}/lzfse.h

%changelog
* Fri Oct 30 2020 Martin Pluskal <mpluskal@suse.com>
- Use proper macro for cmake building
* Mon Feb 19 2018 aloisio@gmx.com
- Update to stable version 1.0, see
  https://github.com/lzfse/lzfse/commits/lzfse-1.0 for details
- Dropped _service
- Spec cleanup
* Sun Dec 18 2016 mpluskal@suse.com
- Update to version 0.0+git.20161117:
  * Update API export to work for CMake and MSVC
  * Fix label error
  * Fix 64-bit check for MSVC
  * Add some tests to verify the build.
  * Add Travis CI support.
  * Add AppVeyor builds.
  * Don't rely on unaligned accesses in the LZVN encoder.
  * Get Visual Studio 12 working.
  * Replace #pragma mark with // MARK:
  * Add const to tables in lzfse_internal.h
* Wed Aug 10 2016 mpluskal@suse.com
- Update to version 0.0+git.20160802:
  * Add extern declarations for linking into C++ code.
  * Avoid pointer arithmetic on void pointers
  * Implement GCC bit scan builtins for MSVC
  * Fix issues related to use of __attribute__
  * Implement jump table as switch for non-GCC
  * Use ptrdiff_t instead of ssize_t
  * Add MSVC fixes for timing and file access
  * Set _POSIX_C_SOURCE to 200112L for gettimeofday
  * Set binary mode on stdin/stdout on Windows
  * Update API export to work for CMake and MSVC
* Mon Jul 11 2016 mpluskal@suse.com
- Update to version 0.0+git.20160620:
  * Allow LZVN to work with inputs shorter than 8 bytes.
  * Converted readme to markdown, added some further information and fixed description of two files being mixed up
  * lzfse_fse.h: correctly detect 64-bit stream for debug macro
  * typo
  * Fix fse_normalize_freq() when passed alphabet with no used symbols
  * reformatted LICENSE
  * merged nemequ changes; fixed end of stream reservation size in LZVN partial encoder; fixed Xcode project with updated README.md file
* Mon Jul 11 2016 mpluskal@suse.com
- Initial package for version 0.0
